@import url("pocoo.css");

a, a.reference, a.footnote-reference {
  color: #185f6d;
  border-color: #185f6d;
}

a:hover {
  color: #2794aa;
  border-color: #2794aa;
}

p.version-warning {
  background-color: #ff8c08;
}
