@import url("pocoo.css");

a, a.reference, a.footnote-reference {
  color: #004b6b;
  border-color: #004b6b;
}

a:hover {
  color: #6d4100;
  border-color: #6d4100;
}

p.version-warning {
  background-color: #004b6b;
}
